@@ -37,9 +37,9 @@ func (n *sourceStateEntryTreeNode) GetNode(targetRelPath RelPath) *sourceStateEn
 
 	node := n
 	for _, childRelPath := range targetRelPath.SplitAll() {
-		var ok bool
-		node, ok = node.children[childRelPath]
-		if !ok {
+		if childNode, ok := node.children[childRelPath]; ok {
+			node = childNode
+		} else {
 			return nil
 		}
 	}
@@ -47,25 +47,17 @@ func (n *sourceStateEntryTreeNode) GetNode(targetRelPath RelPath) *sourceStateEn
 }
 
 // ForEach calls f for each SourceStateEntry in the tree.
-func (n *sourceStateEntryTreeNode) ForEach(
-	targetRelPath RelPath,
-	f func(RelPath, SourceStateEntry) error,
-) error {
-	return n.ForEachNode(
-		targetRelPath,
-		func(targetRelPath RelPath, node *sourceStateEntryTreeNode) error {
-			if node.sourceStateEntry == nil {
-				return nil
-			}
-			return f(targetRelPath, node.sourceStateEntry)
-		},
-	)
+func (n *sourceStateEntryTreeNode) ForEach(targetRelPath RelPath, f func(RelPath, SourceStateEntry) error) error {
+	return n.ForEachNode(targetRelPath, func(targetRelPath RelPath, node *sourceStateEntryTreeNode) error {
+		if node.sourceStateEntry == nil {
+			return nil
+		}
+		return f(targetRelPath, node.sourceStateEntry)
+	})
 }
 
 // ForEachNode calls f for each node in the tree.
-func (n *sourceStateEntryTreeNode) ForEachNode(
-	targetRelPath RelPath, f func(RelPath, *sourceStateEntryTreeNode) error,
-) error {
+func (n *sourceStateEntryTreeNode) ForEachNode(targetRelPath RelPath, f func(RelPath, *sourceStateEntryTreeNode) error) error {
 	switch err := f(targetRelPath, n); {
 	case errors.Is(err, fs.SkipDir):
 		return nil
@@ -98,7 +90,9 @@ func (n *sourceStateEntryTreeNode) Map() map[RelPath]SourceStateEntry {
 // MkdirAll creates SourceStateDirs for all components of targetRelPath if they
 // do not already exist and returns the SourceStateDir of relPath.
 func (n *sourceStateEntryTreeNode) MkdirAll(
-	targetRelPath RelPath, origin SourceStateOrigin, umask fs.FileMode,
+	targetRelPath RelPath,
+	origin SourceStateOrigin,
+	umask fs.FileMode,
 ) (*SourceStateDir, error) {
 	if targetRelPath == EmptyRelPath {
 		return nil, nil
@@ -140,10 +134,7 @@ func (n *sourceStateEntryTreeNode) MkdirAll(
 			var ok bool
 			sourceStateDir, ok = node.sourceStateEntry.(*SourceStateDir)
 			if !ok {
-				return nil, fmt.Errorf(
-					"%s: not a directory",
-					componentRelPaths[0].Join(componentRelPaths[1:i+1]...),
-				)
+				return nil, fmt.Errorf("%s: not a directory", componentRelPaths[0].Join(componentRelPaths[1:i+1]...))
 			}
 			sourceRelPath = sourceRelPath.Join(NewSourceRelPath(sourceStateDir.Attr.SourceName()))
 		}
