@@ -41,6 +41,7 @@ import (
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-xdg/v6"
 	cobracompletefig "github.com/withfig/autocomplete-tools/integrations/cobra"
+	"github.com/zricethezav/gitleaks/v8/detect"
 	"golang.org/x/exp/maps"
 	"golang.org/x/exp/slices"
 	"golang.org/x/term"
@@ -234,6 +235,8 @@ type Config struct {
 	sourceState         *chezmoi.SourceState
 	sourceStateErr      error
 	templateData        *templateData
+	gitleaksDetector    *detect.Detector
+	gitleaksDetectorErr error
 
 	stdin             io.Reader
 	stdout            io.Writer
@@ -575,8 +578,7 @@ func (c *Config) applyArgs(
 		}
 		previousConfigTemplateContentsSHA256 = []byte(configState.ConfigTemplateContentsSHA256)
 	}
-	configTemplatesEmpty := currentConfigTemplateContentsSHA256 == nil &&
-		previousConfigTemplateContentsSHA256 == nil
+	configTemplatesEmpty := currentConfigTemplateContentsSHA256 == nil && previousConfigTemplateContentsSHA256 == nil
 	configTemplateContentsUnchanged := configTemplatesEmpty ||
 		bytes.Equal(currentConfigTemplateContentsSHA256, previousConfigTemplateContentsSHA256)
 	if !configTemplateContentsUnchanged {
@@ -746,8 +748,7 @@ func (c *Config) createAndReloadConfigFile(cmd *cobra.Command) error {
 	// Write the config.
 	configPath := c.init.configPath
 	if c.init.configPath.Empty() {
-		configPath = chezmoi.NewAbsPath(c.bds.ConfigHome).
-			Join(chezmoiRelPath, configTemplate.targetRelPath)
+		configPath = chezmoi.NewAbsPath(c.bds.ConfigHome).Join(chezmoiRelPath, configTemplate.targetRelPath)
 	}
 	if err := chezmoi.MkdirAll(c.baseSystem, configPath.Dir(), fs.ModePerm); err != nil {
 		return err
@@ -903,8 +904,7 @@ func (c *Config) decodeConfigFile(configFileAbsPath chezmoi.AbsPath, configFile
 		return fmt.Errorf("%s: %w", configFileAbsPath, err)
 	}
 
-	if configFile.Git.CommitMessageTemplate != "" &&
-		configFile.Git.CommitMessageTemplateFile != "" {
+	if configFile.Git.CommitMessageTemplate != "" && configFile.Git.CommitMessageTemplateFile != "" {
 		return fmt.Errorf(
 			"%s: cannot specify both git.commitMessageTemplate and git.commitMessageTemplateFile",
 			configFileAbsPath,
@@ -1323,6 +1323,13 @@ func (c *Config) getDiffPagerCmd() (*exec.Cmd, error) {
 	return pagerCmd, nil
 }
 
+func (c *Config) getGitleaksDetector() (*detect.Detector, error) {
+	if c.gitleaksDetector == nil && c.gitleaksDetectorErr == nil {
+		c.gitleaksDetector, c.gitleaksDetectorErr = detect.NewDetectorDefaultConfig()
+	}
+	return c.gitleaksDetector, c.gitleaksDetectorErr
+}
+
 func (c *Config) getHTTPClient() (*http.Client, error) {
 	if c.httpClient != nil {
 		return c.httpClient, nil
@@ -1456,9 +1463,7 @@ func (c *Config) gitCommitMessage(cmd *cobra.Command, status *git.Status) ([]byt
 		"promptInt":    c.promptIntInteractiveTemplateFunc,
 		"promptString": c.promptStringInteractiveTemplateFunc,
 		"targetRelPath": func(source string) string {
-			return chezmoi.NewSourceRelPath(source).
-				TargetRelPath(c.encryption.EncryptedSuffix()).
-				String()
+			return chezmoi.NewSourceRelPath(source).TargetRelPath(c.encryption.EncryptedSuffix()).String()
 		},
 	})
 	var name string
@@ -1993,8 +1998,7 @@ func (c *Config) persistentPreRunRootE(cmd *cobra.Command, args []string) error
 		c.destSystem = chezmoi.NewDryRunSystem(c.destSystem)
 	}
 	if annotations.hasTag(outputsDiff) ||
-		c.Verbose &&
-			(annotations.hasTag(modifiesDestinationDirectory) || annotations.hasTag(modifiesSourceDirectory)) {
+		c.Verbose && (annotations.hasTag(modifiesDestinationDirectory) || annotations.hasTag(modifiesSourceDirectory)) {
 		// If the user has configured a diff pager, then start it as a process.
 		// Otherwise, write the diff output directly to stdout.
 		var writer io.Writer
@@ -2729,6 +2733,7 @@ func newConfigFile(bds *xdg.BaseDirectorySpecification) ConfigFile {
 
 		// Command configurations.
 		Add: addCmdConfig{
+			Secrets:   severityWarning,
 			filter:    chezmoi.NewEntryTypeFilter(chezmoi.EntryTypesAll, chezmoi.EntryTypesNone),
 			recursive: true,
 		},
