@@ -42,12 +42,7 @@ func (c *Config) newEditCmd() *cobra.Command {
 	flags := editCmd.Flags()
 	flags.BoolVarP(&c.Edit.Apply, "apply", "a", c.Edit.Apply, "Apply after editing")
 	flags.VarP(c.Edit.filter.Exclude, "exclude", "x", "Exclude entry types")
-	flags.BoolVar(
-		&c.Edit.Hardlink,
-		"hardlink",
-		c.Edit.Hardlink,
-		"Invoke editor with a hardlink to the source file",
-	)
+	flags.BoolVar(&c.Edit.Hardlink, "hardlink", c.Edit.Hardlink, "Invoke editor with a hardlink to the source file")
 	flags.VarP(c.Edit.filter.Include, "include", "i", "Include entry types")
 	flags.BoolVar(&c.Edit.init, "init", c.Edit.init, "Recreate config file from template")
 	flags.BoolVar(&c.Edit.Watch, "watch", c.Edit.Watch, "Apply on save")
