@@ -41,14 +41,12 @@ func (c *Config) newSecretKeyringCmd() *cobra.Command {
 		Args:  cobra.NoArgs,
 		Short: "Delete a value from keyring",
 		RunE:  c.runSecretKeyringDeleteCmdE,
+		Annotations: newAnnotations(
+			doesNotRequireValidConfig,
+		),
 	}
 	secretKeyringDeletePersistentFlags := keyringDeleteCmd.PersistentFlags()
-	secretKeyringDeletePersistentFlags.StringVar(
-		&c.secret.keyring.delete.service,
-		"service",
-		"",
-		"service",
-	)
+	secretKeyringDeletePersistentFlags.StringVar(&c.secret.keyring.delete.service, "service", "", "service")
 	secretKeyringDeletePersistentFlags.StringVar(&c.secret.keyring.delete.user, "user", "", "user")
 	markPersistentFlagsRequired(keyringDeleteCmd, "service", "user")
 	keyringCmd.AddCommand(keyringDeleteCmd)
@@ -58,14 +56,12 @@ func (c *Config) newSecretKeyringCmd() *cobra.Command {
 		Args:  cobra.NoArgs,
 		Short: "Get a value from keyring",
 		RunE:  c.runSecretKeyringGetCmdE,
+		Annotations: newAnnotations(
+			doesNotRequireValidConfig,
+		),
 	}
 	secretKeyringGetPersistentFlags := keyringGetCmd.PersistentFlags()
-	secretKeyringGetPersistentFlags.StringVar(
-		&c.secret.keyring.get.service,
-		"service",
-		"",
-		"service",
-	)
+	secretKeyringGetPersistentFlags.StringVar(&c.secret.keyring.get.service, "service", "", "service")
 	secretKeyringGetPersistentFlags.StringVar(&c.secret.keyring.get.user, "user", "", "user")
 	markPersistentFlagsRequired(keyringGetCmd, "service", "user")
 	keyringCmd.AddCommand(keyringGetCmd)
@@ -75,14 +71,12 @@ func (c *Config) newSecretKeyringCmd() *cobra.Command {
 		Args:  cobra.NoArgs,
 		Short: "Set a value in keyring",
 		RunE:  c.runSecretKeyringSetCmdE,
+		Annotations: newAnnotations(
+			doesNotRequireValidConfig,
+		),
 	}
 	secretKeyringSetPersistentFlags := keyringSetCmd.PersistentFlags()
-	secretKeyringSetPersistentFlags.StringVar(
-		&c.secret.keyring.set.service,
-		"service",
-		"",
-		"service",
-	)
+	secretKeyringSetPersistentFlags.StringVar(&c.secret.keyring.set.service, "service", "", "service")
 	secretKeyringSetPersistentFlags.StringVar(&c.secret.keyring.set.user, "user", "", "user")
 	secretKeyringSetPersistentFlags.StringVar(&c.secret.keyring.set.value, "value", "", "value")
 	markPersistentFlagsRequired(keyringSetCmd, "service", "user")
